@@ -356,7 +356,7 @@ par(usr)
 ###################################################
 ### code chunk number 22: lda-prelim
 ###################################################
-data("diabetes", package="mclust")
+data("diabetes")
 
 
 ###################################################
@@ -368,7 +368,8 @@ library("lattice")    # load the graphical library
 sup.sym <- trellis.par.get("superpose.symbol")
 sup.sym$pch <- c(1,2,3,4,5)
 trellis.par.set("superpose.symbol", sup.sym)
-cloud.plt <- cloud(insulin ~ glucose + sspg, groups = class, data = diabetes, auto.key=TRUE)
+cloud.plt <- cloud(insulin ~ glucose + sspg, 
+    groups = group, data = diabetes, auto.key=TRUE)
 
 
 ###################################################
@@ -380,7 +381,7 @@ print(cloud.plt)
 ###################################################
 ### code chunk number 25: lda-classic
 ###################################################
-lda <- LdaClassic(class~., data=diabetes)
+lda <- LdaClassic(group~insulin+glucose+sspg, data=diabetes)
 lda
 
 
@@ -393,7 +394,7 @@ predict(lda)
 ###################################################
 ### code chunk number 27: lda-robust
 ###################################################
-rlda <- Linda(class~., data=diabetes)
+rlda <- Linda(group~insulin+glucose+sspg, data=diabetes)
 rlda
 
 rlda.predict <- predict(rlda)
@@ -403,7 +404,7 @@ cat("\nApparent error rate: ", round(rrcov:::.AER(rlda.predict@ct),4))
 ###################################################
 ### code chunk number 28: qda-robust
 ###################################################
-rqda <- QdaCov(class~., data=diabetes)
+rqda <- QdaCov(group~insulin+glucose+sspg, data=diabetes)
 rqda
 rqda.predict <- predict(rqda)
 cat("\nApparent error rate: ", round(rrcov:::.AER(rqda.predict@ct),4))
